@@ -3,7 +3,7 @@
  *
  *             vtk 3D Mesh Writer Code
  *
- *      Copyright 2014-2025, Massachusetts Institute of Technology
+ *      Copyright 2014-2026, Massachusetts Institute of Technology
  *      Licensed under The GNU Lesser General Public License, version 2.1
  *      See http://www.opensource.org/licenses/lgpl-2.1.php
  *
@@ -15,7 +15,11 @@
 
 #include "vtkWriter.h"
 
+//#define WRITE_SURFACE_NEIGBOURS
+
+#ifdef WRITE_SURFACE_NEIGBOURS
 static int surfaceMeshWrite(void *aimInfo, aimMesh *mesh);
+#endif
 static int generalMeshWrite(void *aimInfo, aimMesh *mesh);
 
 #define CINT    const int
@@ -34,8 +38,10 @@ const char *meshExtension()
 int meshWrite(void *aimInfo, aimMesh *mesh)
 {
     int  status; // Function return status
+#ifdef WRITE_SURFACE_NEIGBOURS
     int  nLine=0, nTri=0, nQuad=0;
     int  nTet=0, nPyramid=0, nPrism=0, nHex=0;
+#endif
     int  igroup;
     aimMeshData *meshData = NULL;
 
@@ -62,6 +68,7 @@ int meshWrite(void *aimInfo, aimMesh *mesh)
             goto cleanup;
         }
 
+#ifdef WRITE_SURFACE_NEIGBOURS
         // count the number of element types
         if        (meshData->elemGroups[igroup].elementTopo == aimLine   ) {
             nLine    += meshData->elemGroups[igroup].nElems;
@@ -82,8 +89,10 @@ int meshWrite(void *aimInfo, aimMesh *mesh)
             status = CAPS_MISMATCH;
             goto cleanup;
         }
+#endif
     }
 
+#ifdef WRITE_SURFACE_NEIGBOURS
     /* create surface vtk file if there are only Triangles */
     if (nLine == 0 && nTri > 0 && nQuad == 0 && nTet == 0 && nPyramid == 0 && nPrism == 0 && nHex == 0) {
         status = surfaceMeshWrite(aimInfo, mesh);
@@ -92,13 +101,17 @@ int meshWrite(void *aimInfo, aimMesh *mesh)
     } else {
         status = generalMeshWrite(aimInfo, mesh);
     }
+#else
+    status = generalMeshWrite(aimInfo, mesh);
+    AIM_STATUS(aimInfo, status);
+#endif
 
 cleanup:
     return status;
 }
 
 /* =================================================================== */
-
+#ifdef WRITE_SURFACE_NEIGBOURS
 static int surfaceMeshWrite(void *aimInfo, aimMesh *mesh)
 {
     int  status; // Function return status
@@ -562,7 +575,7 @@ cleanup:
 
     return status;
 }
-
+#endif
 /* =================================================================== */
 
 static int generalMeshWrite(void *aimInfo, aimMesh *mesh)
